SuperTokensAPI class

Constructors

SuperTokensAPI({required String baseURL, required String appOriginURL})

Properties

api ↔ Dio
getter/setter pair
appOriginURL String
final
baseOptions ↔ BaseOptions?
getter/setter pair
baseURL String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptInvitation({required String token, required String email, required String password, required bool termsAndConditions}) Future<Response>
appleSignInUp({required String authorizationCode, required String callbackURL, required String clientId}) Future<Response>
changePassword({required String oldPassword, required String newPassword}) Future<Response>
deleteAccount({required String password}) Future<Response>
forgotPassword({required String email}) Future<Response>
getInvitationDetails({required String token}) Future<Response>
googleSignInUp({required String serverAuthCode, required String callbackURL}) Future<Response>
init() → void
isEmailVerified() Future<Response>
login({required String email, required String password}) Future<Response>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resendVerificationEmail() Future<Response>
resetPassword({required String password, required String token}) Future<Response>
signUp({required String email, required String password}) Future<Response>
toString() String
A string representation of this object.
inherited
verifyEmail({required String method, required String token}) Future<Response>

Operators

operator ==(Object other) bool
The equality operator.
inherited