BaseAuthProvider class abstract

Implementers

Constructors

BaseAuthProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptInvitation({required String token, required String email, required String password, required bool termsAndConditions}) Future<BaseLoginSignUpResponse>
changePassword({required String oldPassword, required String newPassword}) Future<BaseChangePasswordResponse>
deleteAccount({required String password}) Future<BaseDeleteAccountResponse>
forgotPassword({required String email}) Future<BaseForgotPasswordResponse>
getInvitationDetails({required String token}) Future<BaseFetchInvitationResponse>
isUserEmailVerified() Future<bool>
isUserProfileValidated() Future<bool>
loginWithCredentials({required String email, required String password}) Future<BaseLoginSignUpResponse>
logout() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resendVerificationEmail() Future<Response>
resetPassword({required String password, required String token}) Future<BaseResetPasswordResponse>
signInUpWithApple({required String clientId, required String authorizationCode, required String callbackURL}) Future<BaseLoginSignUpResponse>
signInUpWithGoogle({required String serverAuthCode, required String callbackURL}) Future<BaseLoginSignUpResponse>
signUpWithCredentials({required String email, required String password}) Future<BaseLoginSignUpResponse>
toString() String
A string representation of this object.
inherited
verifyEmail({required String method, required String token}) Future<BaseVerifyEmailResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited