SuperTokensAuthProvider class

Inheritance

Constructors

SuperTokensAuthProvider({required String baseURL, required String appOriginURL})

Properties

api SuperTokensAPI
latefinal
appOriginURL String
final
baseURL String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptInvitation({required String token, required String email, required String password, required bool termsAndConditions}) Future<BaseLoginSignUpResponse>
override
changePassword({required String oldPassword, required String newPassword}) Future<BaseChangePasswordResponse>
override
deleteAccount({required String password}) Future<BaseDeleteAccountResponse>
override
forgotPassword({required String email}) Future<BaseForgotPasswordResponse>
override
getInvitationDetails({required String token}) Future<BaseFetchInvitationResponse>
override
isUserEmailVerified() Future<bool>
override
isUserProfileValidated() Future<bool>
override
loginWithCredentials({required String email, required String password}) Future<BaseLoginSignUpResponse>
override
logout() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resendVerificationEmail() Future<Response>
override
resetPassword({required String password, required String token}) Future<BaseResetPasswordResponse>
override
signInUpWithApple({required String clientId, required String authorizationCode, required String callbackURL}) Future<BaseLoginSignUpResponse>
override
signInUpWithGoogle({required String serverAuthCode, required String callbackURL}) Future<BaseLoginSignUpResponse>
override
signUpWithCredentials({required String email, required String password}) Future<BaseLoginSignUpResponse>
override
toString() String
A string representation of this object.
inherited
verifyEmail({required String method, required String token}) Future<BaseVerifyEmailResponse>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited